@@ -12,21 +12,8 @@ import importlib.resources as pkgresources
 
 
 def prinfPath():
-    print(os.path.dirname(os.path.realpath(__file__)))
-
-def prinfPathDirname():
-    print(os.path.dirname(__file__))
-
-def prinfPathRealpath():
-    print(os.path.realpath(__file__))
-
-def prinfLsd():
-    print(pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml"))
-
-def prinf_is_resource():
-    print(pkgresources.is_resource(blurredface_sts_test, "haarcascade_frontalface_default.xml"))
-
-
+    parent = str(os.path.dirname(os.path.realpath(__file__))).replace("\\", "/")
+    print(parent+"/haarcascades/haarcascade_frontalface_default.xml")
 
 #打码函数
 # size为打码的方块大小
@@ -46,7 +33,7 @@ def faceRecognizer(filepath):
     img = cv2.imread(filepath)
     # img = cv2.resize(img,(1920,1080),interpolation=cv2.INTER_CUBIC)
 
-    # parent = os.path.dirname(os.path.realpath(__file__))
+    parent = str(os.path.dirname(os.path.realpath(__file__))).replace("\\","/")
 
     # 转换成灰度图像
     gray_img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
@@ -56,42 +43,46 @@ def faceRecognizer(filepath):
         #"haarcascades/haarcascade_frontalface_default.xml"
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
-        # parent+"\haarcascades\haarcascade_frontalface_default.xml"
+        parent+"/haarcascades/haarcascade_frontalface_default.xml"
         # "haarcascade_frontalface_default.xml"
-        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml")
-
+        # pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml")
+        # "D:/Anaconda/Anaconda3/lib/site-packages/blurredface_sts_test/haarcascade_frontalface_default.xml"
     )
     classifier_alt_tree = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt_tree.xml"
         # "haarcascade_frontalface_alt_tree.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt_tree
-        # parent + "\haarcascades\haarcascade_frontalface_alt_tree.xml"
+        parent + "/haarcascades/haarcascade_frontalface_alt_tree.xml"
         # "haarcascade_frontalface_alt_tree.xml"
-        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt_tree.xml")
+        # pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt_tree.xml")
+        # "D:/Anaconda/Anaconda3/lib/site-packages/blurredface_sts_test/haarcascade_frontalface_alt_tree.xml"
     )
     classifier_alt2 = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt2.xml"
         # "haarcascade_frontalface_alt2.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt2
-        # parent+"\haarcascades\haarcascade_frontalface_alt2.xml"
+        parent+"/haarcascades/haarcascade_frontalface_alt2.xml"
         # "haarcascade_frontalface_alt2.xml"
-        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt2.xml")
+        # pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt2.xml")
+        # "D:/Anaconda/Anaconda3/lib/site-packages/blurredface_sts_test/haarcascade_frontalface_alt2.xml"
     )
     classifier_alt = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt.xml"
         # "haarcascade_frontalface_alt.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt
-        # parent + "\haarcascades\haarcascade_frontalface_alt.xml"
+        parent + "/haarcascades/haarcascade_frontalface_alt.xml"
         # "haarcascade_frontalface_alt.xml"
-        pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt.xml")
+        # pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt.xml")
+        # "D:/Anaconda/Anaconda3/lib/site-packages/blurredface_sts_test/haarcascade_frontalface_alt.xml"
     )
     classifier_ce = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_profileface.xml"
         # "haarcascade_profileface.xml"
         # blurredface_sts_test.haarcascade.haarcascade_profileface
-        # parent+"\haarcascades\haarcascade_profileface.xml"
+        parent+"/haarcascades/haarcascade_profileface.xml"
         # "haarcascade_profileface.xml"
-        pkgresources.path(blurredface_sts_test, "haarcascade_profileface.xml")
+        # pkgresources.path(blurredface_sts_test, "haarcascade_profileface.xml")
+        # "D:/Anaconda/Anaconda3/lib/site-packages/blurredface_sts_test/haarcascade_profileface.xml"
     )
     color = (0, 0, 255)  # 定义绘制颜色
     # 调用识别人脸
